@@ -282,10 +282,11 @@ _DIRECTIVES = {
     "FSA_TOKEN_SECRET", "FSA_TOKEN_SIGN", "FSA_TOKEN_TYPE",
     "FSA_TOKEN_RENEWAL", "FSA_URL_NAME", "FSA_USER_IN_GROUP",
     "FSA_LOGGING_LEVEL", "FSA_CORS", "FSA_CORS_OPTS",
-    "FSA_PASSWORD_LEN", "FSA_PASSWORD_RE",
+    "FSA_PASSWORD_LEN", "FSA_PASSWORD_RE", "FSA_SERVER_ERROR", "FSA_SECURE"
 }
 
 _DEFAULT_CACHE_SIZE = 16384
+_DEFAULT_SERVER_ERROR = 500
 
 
 # actual extension
@@ -302,7 +303,9 @@ class FlaskSimpleAuth:
         self._http_auth = None
         self._pm = None
         self._cache: Optional[Callable[[Any], Callable]] = None
-        # actual main initialization is deferred
+        self._server_error: int = _DEFAULT_SERVER_ERROR
+        self._secure: bool = True
+        # actual main initialization is deferred to `init_app`
         self._initialized = False
 
     def _Resp(self, msg: str, code: int):
@@ -312,6 +315,16 @@ class FlaskSimpleAuth:
     #
     # HOOKS
     #
+    def _check_secure(self):
+        if not request.is_secure and \
+           not (request.remote_addr.startswith("127.") or request.remote_addr == "::1"):
+            msg = f"insecure HTTP request on {request.remote_addr}, allow with FSA_SECURE=False"
+            if self._secure:
+                log.error(msg)
+                return self._Resp("insecure HTTP request denied", self._server_error)
+            else:
+                log.warning(msg)
+
     def _auth_set_user(self):
         """Before request hook to perform early authentication."""
         self._user_set = False
@@ -333,13 +346,12 @@ class FlaskSimpleAuth:
         authorization."""
         self._user_set = False
         self._user = None
-        # should it always return 500?
-        # NOTE this may be too late to prevent a commit
+        # NOTE this may be too late to prevent a commit?
         if res.status_code < 400 and self._need_authorization:
             method, path = request.method, request.path
-            log.warning(f"missing authorization on {method} {path}")
             if self._check and not (self._cors and method == "OPTIONS"):
-                return self._Resp("missing authorization check", 500)
+                log.error(f"missing authorization on {method} {path}")
+                return self._Resp("missing authorization check", self._server_error)
         return res
 
     def _possible_redirect(self, res: Response):
@@ -454,10 +466,14 @@ class FlaskSimpleAuth:
         conf = app.config
         if "FSA_LOGGING_LEVEL" in conf:
             log.setLevel(conf["FSA_LOGGING_LEVEL"])
-        # check directives
+        # check directives for typos
         for name in conf:
             if name[:4] == "FSA_" and name not in _DIRECTIVES:
                 log.warning(f"unexpected directive: {name}")
+        # whether to only allow secure requests
+        self._secure = conf.get("FSA_SECURE", True)
+        # status code for this module internal errors
+        self._server_error = conf.get("FSA_SERVER_ERROR", _DEFAULT_SERVER_ERROR)
         #
         # overall auth setup
         #
@@ -607,7 +623,7 @@ class FlaskSimpleAuth:
         self._userp = conf.get("FSA_PARAM_USER", "USER")
         self._passp = conf.get("FSA_PARAM_PASS", "PASS")
         #
-        # hooks
+        # password authentication and authorization hooks
         #
         if "FSA_GET_USER_PASS" in conf:
             self.get_user_pass(conf["FSA_GET_USER_PASS"])
@@ -641,6 +657,7 @@ class FlaskSimpleAuth:
         #
         # register auth request hooks
         #
+        app.before_request(self._check_secure)
         app.before_request(self._auth_set_user)
         app.after_request(self._auth_after_cleanup)
         app.after_request(self._possible_redirect)
@@ -714,8 +731,8 @@ class FlaskSimpleAuth:
     def _get_fake_auth(self):
         """Return fake user. Only for local tests."""
         assert request.remote_user is None, "do not shadow web server auth"
-        assert request.environ["REMOTE_ADDR"][:4] == "127.", \
-            "fake auth only on localhost"
+        assert request.remote_addr.startswith("127.") or \
+               request.remote_addr == "::1", "fake auth only on localhost"
         params = self._params()
         user = params.get(self._login, None)
         # it could check that the user exists in db
@@ -753,21 +770,19 @@ class FlaskSimpleAuth:
         """Check user password against internal credentials.
 
         Raise an exception if not ok, otherwise simply proceeds."""
-        if not request.is_secure:
-            log.warning("password authentication over an insecure request")
         try:
             ref = self._get_user_pass(user)
         except FSAException as fe:
             raise fe
         except Exception as e:
             log.error(f"get_user_pass failed: {e}")
-            raise FSAException("internal error in get_user_pass", 500)
+            raise FSAException("internal error in get_user_pass", self._server_error)
         if not ref:
             log.debug(f"AUTH (password): no such user ({user})")
             raise FSAException(f"no such user: {user}", 401)
         if not isinstance(ref, (str, bytes)):
             log.error(f"type error in get_user_pass: {type(ref)}, expecting None, str or bytes")
-            raise FSAException("internal error with get_user_pass", 500)
+            raise FSAException("internal error with get_user_pass", self._server_error)
         if not self.check_password(pwd, ref):
             log.debug(f"AUTH (password): invalid password for {user}")
             raise FSAException(f"invalid password for {user}", 401)
@@ -1148,10 +1163,10 @@ class FlaskSimpleAuth:
                         return self._Resp(fe.message, fe.status)
                     except Exception as e:
                         log.error(f"user_in_group failed: {e}")
-                        return self._Resp("internal error in user_in_group", 500)
+                        return self._Resp("internal error in user_in_group", self._server_error)
                     if not isinstance(uig, bool):
                         log.error(f"type error in user_in_group: {type(uig)}, must return a boolean")
-                        return self._Resp("internal error with user_in_group", 500)
+                        return self._Resp("internal error with user_in_group", self._server_error)
                     if uig:
                         try:
                             return fun(*args, **kwargs)
@@ -1167,17 +1182,10 @@ class FlaskSimpleAuth:
     #
     # parameters internal decorator
     #
-    # required:
-    # - None: function parameters are required unless there is a default value
-    # - True: all function parameters are required
-    # - False: all function parameters are optional,
-    #   with default value None unless explicitely provided
+    # translate HTTP or JSON parameters to python parameters based on their
+    # declared names, types and default values.
     #
-    # allparams:
-    # - whether all request parameters are automatically translated to function
-    #   parameters with a str value.
-    #
-    def _parameters(self, required=None, allparams=False):
+    def _parameters(self):
         """Decorator to handle request parameters."""
 
         def decorate(fun: Callable):
@@ -1189,6 +1197,7 @@ class FlaskSimpleAuth:
 
             # parameters types/casts and defaults taken from signature
             sig = inspect.signature(fun)
+            keywords = False
 
             for n, p in sig.parameters.items():
                 if n not in types and \
@@ -1199,38 +1208,38 @@ class FlaskSimpleAuth:
                     typings[n] = _CASTS.get(t, t)
                 if p.default != inspect._empty:  # type: ignore
                     defaults[n] = p.default
+                if p.kind == p.VAR_KEYWORD:
+                    keywords = True
 
             @functools.wraps(fun)
             def wrapper(*args, **kwargs):
+                # NOTE *args and **kwargs are empty before being filled in from HTTP
 
                 # this cannot happen under normal circumstances
                 if self._need_authorization and self._check and \
                         not (self._cors and request.method == 'OPTIONS'):  # pragma: no cover
-                    return self._Resp("missing authorization check", 500)
+                    log.error("missing authorization check in parameter wrapper")
+                    return self._Resp("missing authorization check", self._server_error)
 
                 # translate request parameters to named function parameters
                 params = self._params()
 
                 for p, typing in typings.items():
-                    # parameter HTTP name
-                    pn = p[1:] if p[0] == '_' else p
                     # guess which function parameters are request parameters
+                    # parameter HTTP name
+                    pn = p[1:] if p[0] == '_' and len(p) > 1 else p
                     if p not in kwargs:
+                        # parameter p not yet encountered
                         if pn in params:
                             try:
                                 kwargs[p] = typing(params[pn])
                             except Exception as e:
                                 return self._Resp(f"type error on HTTP parameter \"{pn}\" ({e})", 400)
                         else:
-                            if not required:
-                                if p in defaults:
-                                    kwargs[p] = defaults[p]
-                                else:
-                                    return self._Resp(f"missing HTTP parameter \"{pn}\"", 400)
-                            elif required:
-                                return f"missing HTTP parameter \"{pn}\"", 400
+                            if p in defaults:
+                                kwargs[p] = defaults[p]
                             else:
-                                kwargs[p] = defaults.get(p, None)
+                                return self._Resp(f"missing HTTP parameter \"{pn}\"", 400)
                     else:
                         # possibly recast path parameters if needed
                         if not isinstance(kwargs[p], types[p]):
@@ -1240,7 +1249,7 @@ class FlaskSimpleAuth:
                                 return self._Resp(f"type error on path parameter \"{pn}\": ({e})", 404)
 
                 # possibly add others, without shadowing already provided ones
-                if allparams:
+                if keywords:
                     for p in params:
                         if p not in kwargs:
                             kwargs[p] = params[p]
@@ -1252,14 +1261,14 @@ class FlaskSimpleAuth:
                     return self._Resp(e.message, e.status)
                 except Exception as e:
                     log.error(f"internal error on {request.method} {request.path}: {e}")
-                    return self._Resp(f"internal error on {request.method} {request.path}", 500)
+                    return self._Resp(f"internal error on {request.method} {request.path}", self._server_error)
 
             return wrapper
 
         return decorate
 
     def add_url_rule(self, rule, endpoint=None, view_func=None, authorize=NONE,
-                     auth=None, required=None, allparams=False, **options):
+                     auth=None, **options):
         """Route decorator helper method."""
 
         log.debug(f"adding {rule}")
@@ -1297,7 +1306,7 @@ class FlaskSimpleAuth:
         newpath = "<".join(splits)
 
         assert self._app
-        par = self._parameters(required=required, allparams=allparams)(view_func)
+        par = self._parameters()(view_func)
         aut = self._authorize(*roles, auth=auth)(par)
         return flask.Flask.add_url_rule(self._app, newpath, endpoint=endpoint, view_func=aut, **options)
 
