@@ -20,7 +20,7 @@ app = Flask("Test")
 app.config.update(
     FSA_AUTH = "fake",
     FSA_MODE = "always",
-    FSA_SKIP_PATH = (r"/(register|required)",
+    FSA_SKIP_PATH = (r"/(register|required|_)",
                      r"/(add|div|mul|sub|type|params|any|mis[12]|nogo|one)",
                      r"/(infer|superid|cplx|bool|mail|path|string|auth|f2|myint)"),
     FSA_GET_USER_PASS = get_user_pass,
@@ -129,7 +129,7 @@ def get_type(f: float = None, i: int = None, b: bool = None, s: str = None):
         return "", 200
 
 # accept any parameters…
-@app.route("/params", methods=["GET"], authorize=[ANY], allparams=True)
+@app.route("/params", methods=["GET"], authorize=[ANY])
 def get_params(**kwargs):
     return ' '.join(sorted(kwargs)), 200
 
@@ -279,11 +279,11 @@ def get_auth_ftp():
 def get_403():
     return "missing authorize", 200
 
-@app.route("/required/true", required=True, authorize=ANY)
+@app.route("/required/true", authorize=ANY)
 def get_required_true(s1, s2):
     return s1 + " " + s2, 200
 
-@app.route("/required/false", required=False, authorize=ANY)
+@app.route("/required/false", authorize=ANY)
 def get_required_false(s1 = "hello", s2 = "world"):
     return s1 + " " + s2, 200
 
@@ -308,3 +308,13 @@ def delete_f2():
 def patch_f2():
     return "patch ok", 200
 
+class Len:
+    def __init__(self, s):
+        self._len = len(s)
+    def __str__(self):
+        return str(self._len)
+
+# test underscore params
+@app.get("/_/<_def>", authorize=ANY)
+def get___def(_def: str, _int: int, _: Len, _pass: bool = True):
+    return f"{_def}/{_int}/{_}/{_pass}", 200
